@@ -13,16 +13,22 @@ import sys
 from optparse import make_option
 from types import MethodType
 
+import django
 from django.conf import settings
 from django.core import exceptions
 from django.core.management.base import BaseCommand
 from django.core.management.color import no_style
 from django.core.management.commands.loaddata import Command
-from django.db import connections, transaction, DEFAULT_DB_ALIAS, models
+from django.db import connections, transaction, DEFAULT_DB_ALIAS
 from django.db.backends.creation import BaseDatabaseCreation
-from django.test.simple import DjangoTestSuiteRunner
 from django.utils.importlib import import_module
 
+try:
+    from django.apps import apps
+except ImportError:
+    # Django < 1.7
+    from django.db.models.loading import cache as apps
+
 import nose.core
 
 from django_nose.plugin import DjangoSetUpPlugin, ResultPlugin, TestReorderer
@@ -37,6 +43,12 @@ except NameError:
                 return True
         return False
 
+try:
+    from django.test.runner import DiscoverRunner
+except ImportError:
+    # Django < 1.8
+    from django.test.simple import DjangoTestSuiteRunner as DiscoverRunner
+
 
 __all__ = ['BasicNoseRunner', 'NoseTestSuiteRunner']
 
@@ -121,7 +133,7 @@ def _get_options():
                                        o.action != 'help')
 
 
-class BasicNoseRunner(DjangoTestSuiteRunner):
+class BasicNoseRunner(DiscoverRunner):
     """Facade that implements a nose runner in the guise of a Django runner
 
     You shouldn't have to use this directly unless the additions made by
@@ -143,6 +155,12 @@ class BasicNoseRunner(DjangoTestSuiteRunner):
         for plugin in _get_plugins_from_settings():
             plugins_to_add.append(plugin)
 
+        try:
+            django.setup()
+        except AttributeError:
+            # Setup isn't necessary in Django < 1.7
+            pass
+
         nose.core.TestProgram(argv=nose_argv, exit=False,
                               addplugins=plugins_to_add)
         return result_plugin.result
@@ -231,7 +249,7 @@ def _foreign_key_ignoring_handle(self, *fixture_labels, **options):
             connection.close()
 
 
-def _skip_create_test_db(self, verbosity=1, autoclobber=False):
+def _skip_create_test_db(self, verbosity=1, autoclobber=False, serialize=True):
     """``create_test_db`` implementation that skips both creation and flushing
 
     The idea is to re-use the perfectly good test DB already created by an
@@ -322,7 +340,7 @@ class NoseTestSuiteRunner(BasicNoseRunner):
     def _get_models_for_connection(self, connection):
         """Return a list of models for a connection."""
         tables = connection.introspection.get_table_list(connection.cursor())
-        return [m for m in models.loading.cache.get_models() if
+        return [m for m in apps.get_models() if
                 m._meta.db_table in tables]
 
     def setup_databases(self):
